#!/usr/bin/env python
# coding: utf-8

# In[1]:


import setuptools

setuptools.setup(
name = 'distpygv',
version = '0.2',
author = 'Gaurav Gadekar',
author_email = 'gauravgadekar43@gmail.com',
description = 'Calculation of distance with lat and long',
packages = setuptools.find_packages(),
classifiers = [
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)

